@@ -3,7 +3,7 @@ try:
     from ..tooler import *
     from ..display_tools import *
     from ..teams import *
-    from ..llm_settings import each_message_extension, llm_settings
+    from ..llm_settings import llm_settings
 except ImportError:
     from utils.db import *
 
@@ -49,16 +49,4 @@ if is_online_tools_setting_active():
 
 
 def get_tools():
-    model = load_model_settings()
-
-    if not llm_settings[model]["tools"]:
-        return []
-
-    if is_online_tools_setting_active():
-        tools = get_tiger_tools()
-        if not tools:
-            tools = load_default_tools()
-    else:
-        tools = load_default_tools()
-
-    return tools
+    return []
