@@ -3,9 +3,10 @@
 from flask import Flask, request, jsonify
 import threading
 import time
-
+import pyautogui
 from werkzeug.serving import make_server
 
+from waitress import serve
 app = Flask(__name__)
 
 
@@ -14,6 +15,33 @@ def status():
     return jsonify({"response": True})
 
 
+
+
+def the_input(text, screen, talk):
+    print("Input:", text)
+
+    from .agent.process import process_text_api
+    from .utils.db import (
+        screenshot_path,
+    )
+
+
+
+    if screen != "true":
+        result = process_text_api(text, None)
+    else:
+        screenshot = pyautogui.screenshot()
+        screenshot.save(screenshot_path)
+        result = process_text_api(text, screenshot_path)
+
+    time.sleep(1)
+
+
+
+    return jsonify({"response": result})
+
+
+
 @app.route("/input", methods=["POST"])
 def input():
     """
@@ -23,54 +51,31 @@ def input():
     text = data["text"]
     screen = data["screen"]
     talk = data["talk"]
-    print("Input:", text)
-    from .gpt_computer_assistant import the_main_window, the_input_box
 
-    firsst_text = the_input_box.toPlainText()
+    return the_input(text, screen, talk)
 
-    original_tts = the_main_window.tts_available
 
-    if talk == "true":
-        the_main_window.tts_available = True
-        the_main_window.manuel_stop = True
 
-    if screen != "true":
-        the_main_window.button_handler.input_text(text)
+
+
+@app.route("/request", methods=["POST"])
+def the_request():
+    """
+    This function receives input from the user and returns the response.
+    """
+    data = request.json
+    the_request = data["request"]
+    the_response = data["response"]
+    if "screen" in data:
+        screen = data["screen"]
     else:
-        the_main_window.button_handler.input_text_screenshot(text)
+        screen = "false"
 
-    time.sleep(1)
+    combined = the_request + "\n" + the_response
 
-    return_okay = False
-    
+    return the_input(combined, screen, "false")
 
-    while return_okay == False:
-        response = the_input_box.toPlainText()
 
-        if response == firsst_text:
-            time.sleep(0.3)
-            continue
-
-        if response.startswith("System:"):
-            time.sleep(0.3)
-            continue
-
-        if response.startswith("Thinking..."):
-            time.sleep(0.3)
-            continue
-
-        return_okay = True
-
-    while not the_main_window.state == "idle":
-        time.sleep(0.3)
-
-        
-
-    
-
-    the_main_window.tts_available = original_tts
-
-    return jsonify({"response": response})
 
 
 @app.route("/screenshot", methods=["POST"])
@@ -131,9 +136,7 @@ def profile():
     from .utils.db import set_profile
 
     set_profile(profile)
-    from .gpt_computer_assistant import the_main_window
 
-    the_main_window.update_from_thread("Profile set to " + profile)
     return jsonify({"response": "Profile set to " + profile})
 
 
@@ -145,9 +148,7 @@ def reset_memory():
     from .agent.chat_history import clear_chat_history
 
     clear_chat_history()
-    from .gpt_computer_assistant import the_main_window
 
-    the_main_window.update_from_thread("Memory reset")
     return jsonify({"response": "Memory reset"})
 
 
@@ -159,9 +160,7 @@ def enable_predefined_agents():
     from .utils.db import activate_predefined_agents_setting
 
     activate_predefined_agents_setting()
-    from .gpt_computer_assistant import the_main_window
 
-    the_main_window.update_from_thread("Predefined agents enabled")
     return jsonify({"response": "Predefined agents enabled"})
 
 
@@ -173,9 +172,7 @@ def disable_predefined_agents():
     from .utils.db import deactivate_predefined_agents_setting
 
     deactivate_predefined_agents_setting()
-    from .gpt_computer_assistant import the_main_window
 
-    the_main_window.update_from_thread("Predefined agents disabled")
     return jsonify({"response": "Predefined agents disabled"})
 
 
@@ -187,9 +184,7 @@ def enable_online_tools():
     from .utils.db import activate_online_tools_setting
 
     activate_online_tools_setting()
-    from .gpt_computer_assistant import the_main_window
 
-    the_main_window.update_from_thread("Online tools enabled")
     return jsonify({"response": "Online tools enabled"})
 
 
@@ -201,9 +196,7 @@ def disable_online_tools():
     from .utils.db import deactivate_online_tools_setting
 
     deactivate_online_tools_setting()
-    from .gpt_computer_assistant import the_main_window
 
-    the_main_window.update_from_thread("Online tools disabled")
     return jsonify({"response": "Online tools disabled"})
 
 
@@ -701,8 +694,25 @@ def mouse_scroll_up():
     return jsonify({"response": f"Mouse scrolled up by {amount}"})
 
 
+@app.route("/stop_server", methods=["POST"])
+def stop_server():
 
 
+    try:
+        try:
+            from .gpt_computer_assistant import the_main_window
+            the_main_window.close()
+        except ImportError:
+            from gpt_computer_assistant import the_main_window
+            the_main_window.close()
+    except:
+        pass
+
+    
+
+    stop_api()
+    exit(0)
+
 
 
 
@@ -725,15 +735,18 @@ class ServerThread(threading.Thread):
 server_thread = None
 
 
-def start_api():
-    global server_thread
-    if server_thread is None:
-        server_thread = ServerThread(app, "0.0.0.0", 7541)
-        server_thread.start()
-        print("API started")
-    else:
-        print("API is already running")
+def start_api(api=False):
+    if api == False:
+        global server_thread
+        if server_thread is None:
+            server_thread = ServerThread(app, "0.0.0.0", 7541)
+            server_thread.start()
+            print("API started")
+        else:
+            print("API is already running")
 
+    else:
+        serve(app, host="0.0.0.0", port=7541)
 
 def stop_api():
     global server_thread
